@@ -5,7 +5,7 @@ use warnings;
 package Log::Any::Adapter::File;
 
 # ABSTRACT: Simple adapter for logging to files
-our $VERSION = '1.046'; # TRIAL
+our $VERSION = '1.047'; # TRIAL
 
 use Config;
 use Fcntl qw/:flock/;
@@ -25,11 +25,15 @@ sub new {
 
 sub init {
     my $self = shift;
-    if ( exists $self->{log_level} ) {
-        $self->{log_level} = Log::Any::Adapter::Util::numeric_level( $self->{log_level} )
-            unless $self->{log_level} =~ /^\d+$/;
+    if ( exists $self->{log_level} && $self->{log_level} =~ /\D/ ) {
+        my $numeric_level = Log::Any::Adapter::Util::numeric_level( $self->{log_level} );
+        if ( !$numeric_level ) {
+            require Carp;
+            Carp::carp( sprintf 'Invalid log level "%s". Defaulting to "%s"', $self->{log_level}, 'trace' );
+        }
+        $self->{log_level} = $numeric_level;
     }
-    else {
+    if ( !$self->{log_level} ) {
         $self->{log_level} = $trace_level;
     }
     my $file = $self->{file};
@@ -76,7 +80,7 @@ Log::Any::Adapter::File - Simple adapter for logging to files
 
 =head1 VERSION
 
-version 1.046
+version 1.047
 
 =head1 SYNOPSIS
 
