@@ -5,7 +5,7 @@ use warnings;
 package Log::Any::Adapter::Stderr;
 
 # ABSTRACT: Simple adapter for logging to STDERR
-our $VERSION = '1.046'; # TRIAL
+our $VERSION = '1.047'; # TRIAL
 
 use Log::Any::Adapter::Util ();
 
@@ -16,12 +16,15 @@ my $trace_level = Log::Any::Adapter::Util::numeric_level('trace');
 
 sub init {
     my ($self) = @_;
-    if ( exists $self->{log_level} ) {
-        $self->{log_level} =
-          Log::Any::Adapter::Util::numeric_level( $self->{log_level} )
-          unless $self->{log_level} =~ /^\d+$/;
+    if ( exists $self->{log_level} && $self->{log_level} =~ /\D/ ) {
+        my $numeric_level = Log::Any::Adapter::Util::numeric_level( $self->{log_level} );
+        if ( !$numeric_level ) {
+            require Carp;
+            Carp::carp( sprintf 'Invalid log level "%s". Defaulting to "%s"', $self->{log_level}, 'trace' );
+        }
+        $self->{log_level} = $numeric_level;
     }
-    else {
+    if ( !$self->{log_level} ) {
         $self->{log_level} = $trace_level;
     }
 }
@@ -59,7 +62,7 @@ Log::Any::Adapter::Stderr - Simple adapter for logging to STDERR
 
 =head1 VERSION
 
-version 1.046
+version 1.047
 
 =head1 SYNOPSIS
 
