@@ -5,7 +5,7 @@ use warnings;
 package Log::Any::Proxy;
 
 # ABSTRACT: Log::Any generator proxy object
-our $VERSION = '1.046'; # TRIAL
+our $VERSION = '1.047'; # TRIAL
 
 use Log::Any::Adapter::Util ();
 use overload;
@@ -115,7 +115,7 @@ Log::Any::Proxy - Log::Any generator proxy object
 
 =head1 VERSION
 
-version 1.046
+version 1.047
 
 =head1 SYNOPSIS
 
@@ -261,6 +261,46 @@ string is then returned.
 Numeric levels range from 0 (emergency) to 8 (trace).  Constant functions
 for these levels are available from L<Log::Any::Adapter::Util>.
 
+=head1 TIPS
+
+=head2 UTF-8 in Data Structures
+
+If you have high-bit characters in a data structure being passed to a log
+method, Log::Any will output that data structure with the high-bit
+characters encoded as C<\x{###}>, Perl's escape sequence for high-bit
+characters. This is because the L<Data::Dumper> module escapes those
+characters.
+
+    use utf8;
+    use Log::Any qw( $log );
+    my @data = ( "Привет мир" ); # Hello, World!
+    $log->infof("Got: %s", \@data);
+    # Got: ["\x{41f}\x{440}\x{438}\x{432}\x{435}\x{442} \x{43c}\x{438}\x{440}"]
+
+If you want to instead display the actual characters in your log file or
+terminal, you can use the L<Data::Dumper::AutoEncode> module. To wire this
+up into Log::Any, you must pass a custom C<formatter> sub:
+
+    use utf8;
+    use Data::Dumper::AutoEncode;
+
+    sub log_formatter {
+        my ( $category, $level, $format, @params ) = @_;
+        # Run references through Data::Dumper::AutoEncode
+        @params = map { ref $_ ? eDumper( $_ ) : $_ } @params;
+        return sprintf $format, @params;
+    }
+
+    use Log::Any '$log', formatter => \&log_formatter;
+
+This formatter changes the output to:
+
+	Got: $VAR1 = [
+			  'Привет мир'
+			];
+
+Thanks to L<@denis-it|https://github.com/denis-it> for this tip!
+
 =head1 AUTHORS
 
 =over 4
